@@ -3,21 +3,9 @@ package ExtUtils::CBuilder::Platform::Unix;
 use strict;
 use ExtUtils::CBuilder::Base;
 
-use vars qw($VERSION @ISA);
-$VERSION = '0.27_07';
+use vars qw(@ISA);
 @ISA = qw(ExtUtils::CBuilder::Base);
 
-sub link_executable {
-  my $self = shift;
-
-  # On some platforms (which ones??) $Config{cc} seems to be a better
-  # bet for linking executables than $Config{ld}.  Cygwin is a notable
-  # exception.
-  local $self->{config}{ld} =
-    $self->{config}{cc} . " " . $self->{config}{ldflags};
-  return $self->SUPER::link_executable(@_);
-}
-
 sub link {
   my $self = shift;
   my $cf = $self->{config};
